@@ -2,10 +2,9 @@
 This module provides a @concurrent decorator primitive to
 offload computations from mitmproxy's main master thread.
 """
-from __future__ import absolute_import, print_function, division
 
-from mitmproxy import controller
-from netlib import basethread
+from mitmproxy import eventsequence
+from mitmproxy.types import basethread
 
 
 class ScriptThread(basethread.BaseThread):
@@ -13,7 +12,7 @@ class ScriptThread(basethread.BaseThread):
 
 
 def concurrent(fn):
-    if fn.__name__ not in controller.Events - {"start", "configure", "tick"}:
+    if fn.__name__ not in eventsequence.Events - {"start", "configure", "tick"}:
         raise NotImplementedError(
             "Concurrent decorator not supported for '%s' method." % fn.__name__
         )
@@ -30,4 +29,8 @@ def concurrent(fn):
             "script.concurrent (%s)" % fn.__name__,
             target=run
         ).start()
-    return _concurrent
+    # Support @concurrent for class-based addons
+    if "." in fn.__qualname__:
+        return staticmethod(_concurrent)
+    else:
+        return _concurrent
