@@ -6,11 +6,9 @@ setup(
     py_modules=["rtool"],
     install_requires=[
         "click>=6.2, <7.0",
-        "twine>=1.6.5, <1.8",
-        "virtualenv>=14.0.5, <15.1",
-        "wheel>=0.29.0, <0.30",
-        "six>=1.10.0, <1.11",
-        "pysftp>=0.2.8, !=0.2.9, <0.3",
+        "twine>=1.6.5, <1.9",
+        "pysftp==0.2.8",
+        "cryptography>=1.6, <1.7",
     ],
     entry_points={
         "console_scripts": [
