@@ -1,4 +1,5 @@
 from typing import List
+import pytest
 
 from mitmproxy.stateobject import StateObject
 
@@ -17,6 +18,9 @@ class Child(StateObject):
         obj.set_state(state)
         return obj
 
+    def __eq__(self, other):
+        return isinstance(other, Child) and self.x == other.x
+
 
 class Container(StateObject):
     def __init__(self):
@@ -60,4 +64,18 @@ def test_container_list():
         "child": None,
         "children": [{"x": 42}, {"x": 44}]
     }
-    assert len(a.copy().children) == 2
+    copy = a.copy()
+    assert len(copy.children) == 2
+    assert copy.children is not a.children
+    assert copy.children[0] is not a.children[0]
+
+
+def test_too_much_state():
+    a = Container()
+    a.child = Child(42)
+    s = a.get_state()
+    s['foo'] = 'bar'
+    b = Container()
+
+    with pytest.raises(RuntimeWarning):
+        b.set_state(s)
