@@ -9,23 +9,23 @@ ContentViewOptions.propTypes = {
     message: React.PropTypes.object.isRequired,
 }
 
-function ContentViewOptions(props) {
-    const { flow, message, uploadContent, readonly, contentViewDescription } = props
+function ContentViewOptions({ flow, message, uploadContent, readonly, contentViewDescription }) {
     return (
         <div className="view-options">
-            <ViewSelector message={message}/>
+            {readonly ? <ViewSelector message={message}/> : <span><b>View:</b> edit</span>}
             &nbsp;
             <DownloadContentButton flow={flow} message={message}/>
             &nbsp;
-            <UploadContentButton uploadContent={uploadContent}/>
+            {!readonly && <UploadContentButton uploadContent={uploadContent}/> }
             &nbsp;
-            <span>{contentViewDescription}</span>
+            {readonly && <span>{contentViewDescription}</span>}
         </div>
     )
 }
 
 export default connect(
     state => ({
-        contentViewDescription: state.ui.flow.viewDescription
+        contentViewDescription: state.ui.flow.viewDescription,
+        readonly: !state.ui.flow.modifiedFlow,
     })
 )(ContentViewOptions)
