@@ -1,20 +1,17 @@
-import React, { Component, PropTypes } from 'react'
-import { connect } from 'react-redux'
-import FilterInput from './FilterInput'
-import { update as updateSettings } from '../../ducks/settings'
-import { updateFilter, updateHighlight } from '../../ducks/flowView'
+import React, { Component, PropTypes } from "react"
+import { connect } from "react-redux"
+import FilterInput from "./FilterInput"
+import { update as updateSettings } from "../../ducks/settings"
+import { setFilter, setHighlight } from "../../ducks/flows"
 
 MainMenu.title = "Start"
 
 export default function MainMenu() {
     return (
-        <div>
-            <div className="menu-row">
-                <FlowFilterInput/>
-                <HighlightInput/>
-                <InterceptInput/>
-            </div>
-            <div className="clearfix"></div>
+        <div className="menu-main">
+            <FlowFilterInput/>
+            <HighlightInput/>
+            <InterceptInput/>
         </div>
     )
 }
@@ -31,20 +28,20 @@ const InterceptInput = connect(
 
 const FlowFilterInput = connect(
     state => ({
-        value: state.flowView.filter || '',
+        value: state.flows.filter || '',
         placeholder: 'Search',
         type: 'search',
         color: 'black'
     }),
-    { onChange: updateFilter }
+    { onChange: setFilter }
 )(FilterInput);
 
 const HighlightInput = connect(
     state => ({
-        value: state.flowView.highlight || '',
+        value: state.flows.highlight || '',
         placeholder: 'Highlight',
         type: 'tag',
         color: 'hsl(48, 100%, 50%)'
     }),
-    { onChange: updateHighlight }
+    { onChange: setHighlight }
 )(FilterInput);
